package com.fwk.config;

import java.util.HashMap;
import java.util.Map;

import com.fwk.actions.ActionForward;
import com.fwk.config.actions.ActionConfig;
import com.fwk.config.exceptions.ExceptionConfig;
import com.fwk.config.forms.FormConfig;
import com.fwk.config.resources.MessageResourcesConfig;

/**
 * Classe que cont la informaci del framework. La informaci s obtinguda del
 * fitxer de configuraci en el moment d'arrencar el serlvet
 * 
 * @author fjbravo
 * 
 */
public class Configuration {

	// Accions creades al fitxer de configuraci
	private Map<String, ActionConfig> actionsMap;

	// Formularis creats al fitxer de configuracis
	private Map<String, FormConfig> formsMap;
	
	// Configuraci dels missatges
	private MessageResourcesConfig messagesConfig;
	
	//Adreces globals a les que podem redireccionar una acci
	private Map<String, ActionForward> globalForwards; 
	
	//Excepcions globals que tenim definides
	private Map<String, ExceptionConfig> globalExceptions;
	
	
	// Constructor
	public Configuration() {
		actionsMap = new HashMap<String, ActionConfig>();
		formsMap = new HashMap<String, FormConfig>();
		globalForwards = new HashMap<String,ActionForward>();
		globalExceptions = new HashMap<String,ExceptionConfig>();
	}

	/**
	 * Afegim la configuraci dels missatges
	 * @param messageResourcesConfig
	 */
	public void addMessagesConfig( MessageResourcesConfig messageResourcesConfig){
		this.messagesConfig = messageResourcesConfig;
	}
	
	
	/**
	 * Mtode per a afegir una adrea global a la configuraci del framework
	 * @param forward
	 */
	public void addGlobalForward(ActionForward forward){
		if(globalForwards != null)
			this.globalForwards.put(forward.getNom(), forward);
	}
	
	public void addGlobalException(ExceptionConfig exceptionConfig){
		if(globalExceptions != null)
			this.globalExceptions.put(exceptionConfig.getType(), exceptionConfig);
	}
	
	
	/**
	 * Afegim una acci a la configuraci
	 * 
	 * @param actionConfig
	 */
	public void addActionConfiguration(ActionConfig actionConfig) {
		if (actionsMap != null){
			actionConfig.setGlobalConfiguration(this);
			actionsMap.put(actionConfig.getPath(), actionConfig);	
		}
	}

	/**
	 * Afegim un formulari a la configuraci
	 * 
	 * @param formConfig
	 */
	public void addFormConfiguration(FormConfig formConfig) {
		if (formsMap != null)
			this.formsMap.put(formConfig.getNom(), formConfig);
	}

	// GETTERS i SETTERS

	public Map<String, ActionConfig> getActionsMap() {
		return actionsMap;
	}

	public void setActionsMap(Map<String, ActionConfig> actionsMap) {
		this.actionsMap = actionsMap;
	}

	public Map<String, FormConfig> getFormsMap() {
		return formsMap;
	}

	public void setFormsMap(Map<String, FormConfig> formsMap) {
		this.formsMap = formsMap;
	}


	public MessageResourcesConfig getMessagesConfig() {
		return messagesConfig;
	}


	public void setMessagesConfig(MessageResourcesConfig messagesConfig) {
		this.messagesConfig = messagesConfig;
	}

	public Map<String, ActionForward> getGlobalForwards() {
		return globalForwards;
	}

	public void setGlobalForwards(Map<String, ActionForward> globalForwards) {
		this.globalForwards = globalForwards;
	}

	public Map<String, ExceptionConfig> getGlobalExceptions() {
		return globalExceptions;
	}

	public void setGlobalExceptions(Map<String, ExceptionConfig> globalExceptions) {
		this.globalExceptions = globalExceptions;
	}




}
