package com.fwk.config.actions;

import java.util.HashMap;
import java.util.Map;

import com.fwk.actions.ActionForward;
import com.fwk.config.Configuration;
import com.fwk.config.exceptions.ExceptionConfig;

/**
 * Classe que representa la configuraci concreta d'una acci creada
 * a travs del fitxer de configuraci del framework
 * @author fjbravo
 *
 */
public class ActionConfig {

	//Nom de l'acci
	private String nom;
	
	//Nom de la classe que l'implementa
	private String type;
	
	//Indica el mtode que s'executar 
	private String parametre;
	
	//Indica si s'ha de validar el formulari associat
	private String validate;
	
	//Indica el path de l'acci
	private String path;
	
	//Nom del formulari que t associat l'acci
	private String formulari;
	
	//Adreces a les que es pot redirigir
	// KEY--> Path de l'acci
	private Map<String, ActionForward> forwards;
	
	//Exceptions configurades a travs del fitxer de configuraci
	// KEY--> Tipus d'excepci
	private Map<String,ExceptionConfig> exceptions;
	
	//Accs a la configuraci global del framework
	private Configuration globalConfiguration;
	
	/**
	 * CONSTRUCTOR
	 */
	public ActionConfig(){
		forwards = new HashMap<String, ActionForward>();
		exceptions = new HashMap<String,ExceptionConfig>();
	}

	
	/**
	 * Mtode que cerca una adrea a la que redireccionar. Primer cerca en els forwards de la prpia acci, en cas de no trobar-lo 
	 * cerca a als globalForwards
	 * @param name
	 * @return
	 */
	public ActionForward findForward(String name){
		ActionForward resultForward = null;
		//En primer lloc busquem l'adrea dintre del mapeig de la prpia acci
		resultForward = getForwards().get(name);
		if(resultForward != null)
			return resultForward;
		
		//En cas de no trobar una adrea, busquem a les adreces globals
		Map<String,ActionForward> globalForwards = getGlobalConfiguration().getGlobalForwards();
		if(globalForwards != null && !globalForwards.isEmpty()){
			resultForward = globalForwards.get(name);
			return resultForward;
		}
		
		//Si no hem trobat cap forward, retornem null
		return resultForward;
	}
	
	/**
	 * Mtode que serveix per a buscar una excepti a la configuraci de l'acci o a les excepcions globals
	 * @param exceptionName
	 * @return
	 */
	public ExceptionConfig findException(String exceptionType){
		ExceptionConfig resultExceptionConfig = null;
		
		resultExceptionConfig = getExceptions().get(exceptionType);
		if(resultExceptionConfig != null)
			return resultExceptionConfig;
		
		//Si no la trobem a les exceptions configurades per la prpia acci.
		//Procedirem a buscar-la a les excepcions globals
		Map<String,ExceptionConfig> globalExceptions = getGlobalConfiguration().getGlobalExceptions();
		if(globalExceptions != null && !globalExceptions.isEmpty()){
			resultExceptionConfig = globalExceptions.get(exceptionType);
			return resultExceptionConfig;
		}
		return resultExceptionConfig;
	}
	
	

	/**
	 * Mtode que afegeix una excepci a la configuraci d'una acci
	 */
	public void addExceptionConfig(ExceptionConfig exceptionConfig){
		if(exceptionConfig != null){
			if(exceptionConfig.getType() != null && !exceptionConfig.getType().equals(""))
				exceptions.put(exceptionConfig.getType(), exceptionConfig);
		}
	}
	
	
	/**
	 * Mtode per afegir una destinaci a una acci 
	 */
	public void addForward(ActionForward actionForward){
		if(forwards != null)
			forwards.put(actionForward.getNom(), actionForward);
	}

	
	//GETTERS i SETTERS
	public String getNom() {
		return nom;
	}



	public void setNom(String nom) {
		this.nom = nom;
	}



	public String getType() {
		return type;
	}



	public void setType(String type) {
		this.type = type;
	}



	public String getParametre() {
		return parametre;
	}



	public void setParametre(String parametre) {
		this.parametre = parametre;
	}



	public String getValidate() {
		return validate;
	}



	public void setValidate(String validate) {
		this.validate = validate;
	}



	public String getPath() {
		return path;
	}



	public void setPath(String path) {
		this.path = path;
	}
	
	public String getFormulari() {
		return formulari;
	}


	public void setFormulari(String formulari) {
		this.formulari = formulari;
	}


	public Map<String, ActionForward> getForwards() {
		return forwards;
	}


	public void setForwards(Map<String, ActionForward> forwards) {
		this.forwards = forwards;
	}


	public Configuration getGlobalConfiguration() {
		return globalConfiguration;
	}


	public void setGlobalConfiguration(Configuration globalConfiguration) {
		this.globalConfiguration = globalConfiguration;
	}

	public Map<String, ExceptionConfig> getExceptions() {
		return exceptions;
	}

	public void setExceptions(Map<String, ExceptionConfig> exceptions) {
		this.exceptions = exceptions;
	}



	
}
