/**
 * 
 */
package com.fwk.controller;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.digester.Digester;
import org.apache.commons.digester.xmlrules.DigesterLoader;

import com.fwk.config.Configuration;
import com.fwk.constants.GlobalConstants;
import com.fwk.i18.MessageResourcesReader;
import com.fwk.processor.Processor;

/**
 * Controlador principal del framework encarregat de rebre les peticions i
 * delegar el seu tractament.
 * 
 * @author fjbravo
 * 
 */
public class ServletController extends HttpServlet {

	private static final long serialVersionUID = 1L;
	
	//Objecte que representa la configuraci del framework carregada al arrencar el Framework
	private Configuration servletConfiguration;
	
	//Gestor dels missatges generals del framework
	private MessageResourcesReader internalMessagesHandler;

	@Override
	public void init() {
		String configFile = getInitParameter("configFile");
		Digester digester;
		try {
			//Primer llegim la configuraci del fitxer de properties
			digester = DigesterLoader.createDigester(getClass().getClassLoader().getResource("digester/digester-rules.xml"));
			digester.setUseContextClassLoader(true);
			digester.setClassLoader(getClass().getClassLoader());
			servletConfiguration = (Configuration)digester.parse(this.getServletContext().getResourceAsStream(configFile));
			internalMessagesHandler = new MessageResourcesReader(GlobalConstants.GLOBAL_RESOURCES,getClass().getClassLoader());
			if(servletConfiguration.getMessagesConfig().getUrlBase() != null)
				this.getServletContext().setAttribute(GlobalConstants.GLOBAL_PROPERTIES_LOCATION, servletConfiguration.getMessagesConfig().getUrlBase());
		} catch (Exception e) {
			destroy();
		}
	}


	@Override
	public void doGet(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		doPost(req, res);
	}

	@Override
	public void doPost(HttpServletRequest req, HttpServletResponse res)
			throws ServletException, IOException {
		
		Processor requestProcessor = new Processor();
		requestProcessor.initConfig(this, getServletConfiguration());
		requestProcessor.process(req, res);
	}
	

	//MTODES ACCESSORIS DE LA CONFIGURACIs
	public Configuration getServletConfiguration() {
		return servletConfiguration;
	}

	public void setServletConfiguration(Configuration servletConfiguration) {
		this.servletConfiguration = servletConfiguration;
	}


	public MessageResourcesReader getInternalMessagesHandler() {
		return internalMessagesHandler;
	}


	public void setInternalMessagesHandler(
			MessageResourcesReader internalMessagesHandler) {
		this.internalMessagesHandler = internalMessagesHandler;
	}

	
}
